from sys import platform
from importlib import import_module


def notify(subject, config, message=None, device=None):
    for os in ['linux', 'win32', 'darwin']:
        if platform.startswith(os):
            module = import_module('ntfy.backends.{}'.format(os))
            module.notify(subject=subject, config=config,
                          message=message, device=device)
            break



import dbus
from os import path

ICON = path.abspath(path.join(path.split(path.split(__file__)[0])[0],
                              'icon.png'))

def notify(subject, config, message=None, device=None):
    bus = dbus.SessionBus()
    dbus_obj = bus.get_object(
        'org.freedesktop.Notifications', '/org/freedesktop/Notifications')
    dbus_iface = dbus.Interface(
        dbus_obj, dbus_interface='org.freedesktop.Notifications')

    dbus_iface.Notify('ntfy', 0, ICON, subject, message, [], {}, -1)


import requests


def notify(subject, config, message=None, device=None):
    """
    Required config keys:
        * 'access_token'
    """

    data = {
        'type': 'note',
        'title': subject,
    }
    if message is not None:
        data['body'] = message
    if device is not None:
        data['device_iden'] = device

    headers = {'Access-Token': config['access_token']}

    resp = requests.post('https://api.pushbullet.com/v2/pushes',
                         data=data, headers=headers)

    resp.raise_for_status()



import requests


def notify(message, config, subject=None, device=None):
    """
    Required config keys:
        * 'api_token'
        * 'user_key'
    """

    data = {
        'message': message,
        'token': config['api_token'],
        'user': config['user_key']
    }
    if subject:
        data['title'] = subject
    if device:
        data['device'] = device

    resp = requests.post('https://api.pushover.net/1/messages.json',
                         data=data)

    resp.raise_for_status()
